@@ -7,6 +7,7 @@ import plistlib
 import sys
 import uuid
 from pathlib import Path
+from typing import Mapping
 
 from packaging.version import Version
 
@@ -14,6 +15,7 @@ from pymobiledevice3 import usbmux
 from pymobiledevice3.ca import ca_do_everything
 from pymobiledevice3.exceptions import *
 from pymobiledevice3.service_connection import ServiceConnection
+from pymobiledevice3.usbmux import PlistMuxConnection
 from pymobiledevice3.utils import sanitize_ios_version
 
 # we store pairing records and ssl keys in ~/.pymobiledevice3
@@ -51,7 +53,8 @@ def reconnect_on_remote_close(f):
 
             # now we re-establish the connection
             self.logger.debug('remote device closed the connection. reconnecting...')
-            self.service = ServiceConnection.create(self.udid, self.SERVICE_PORT)
+            self.service = ServiceConnection.create(self.udid, self.SERVICE_PORT,
+                                                    connection_type=self.usbmux_device.connection_type)
             self.validate_pairing()
             return f(*args, **kwargs)
 
@@ -62,8 +65,8 @@ class LockdownClient(object):
     DEFAULT_CLIENT_NAME = 'pyMobileDevice'
     SERVICE_PORT = 62078
 
-    def __init__(self, udid=None, client_name=DEFAULT_CLIENT_NAME, autopair=True):
-        device = usbmux.select_device(udid)
+    def __init__(self, udid=None, client_name=DEFAULT_CLIENT_NAME, autopair=True, connection_type=None):
+        device = usbmux.select_device(udid, connection_type=connection_type)
         if device is None:
             if udid:
                 raise ConnectionFailedError()
@@ -74,7 +77,7 @@ class LockdownClient(object):
         self.logger = logging.getLogger(__name__)
         self.paired = False
         self.SessionID = None
-        self.service = ServiceConnection.create(udid, self.SERVICE_PORT)
+        self.service = ServiceConnection.create(udid, self.SERVICE_PORT, connection_type=device.connection_type)
         self.host_id = self.generate_host_id()
         self.system_buid = None
         self.label = client_name
@@ -106,7 +109,8 @@ class LockdownClient(object):
             self.pair()
             if not self.validate_pairing():
                 raise FatalPairingError()
-            self.service = ServiceConnection.create(udid, self.SERVICE_PORT)
+            self.service = ServiceConnection.create(udid, self.SERVICE_PORT,
+                                                    connection_type=self.usbmux_device.connection_type)
 
     def __enter__(self):
         return self
@@ -119,6 +123,21 @@ class LockdownClient(object):
         res = self.service.recv_plist()
         return res.get('Type')
 
+    @property
+    def device_info(self) -> Mapping:
+        result = dict(self.all_values)
+        result.update({'ConnectionType': self.usbmux_device.connection_type, 'Serial': self.usbmux_device.serial})
+        result.update(self.get_value('com.apple.mobile.wireless_lockdown'))
+        return result
+
+    @property
+    def enable_wifi_connections(self):
+        return self.get_value('com.apple.mobile.wireless_lockdown').get('EnableWifiConnections', False)
+
+    @enable_wifi_connections.setter
+    def enable_wifi_connections(self, value: bool):
+        self.set_value(value, 'com.apple.mobile.wireless_lockdown', 'EnableWifiConnections')
+
     @property
     def ecid(self):
         return self.all_values['UniqueChipID']
@@ -179,14 +198,12 @@ class LockdownClient(object):
         return pair_record
 
     def get_usbmux_pairing_record(self):
-        mux = usbmux.MuxConnection.create_socket()
-        client = usbmux.PlistProtocol(mux)
-        try:
-            pairing_record = client.get_pair_record(self.udid)
-            mux.close()
-            return pairing_record
-        except PyMobileDevice3Exception:
+        mux = usbmux.create_mux()
+        if not isinstance(mux, PlistMuxConnection):
             return None
+        pairing_record = mux.get_pair_record(self.udid)
+        mux.close()
+        return pairing_record
 
     def get_local_pairing_record(self):
         self.logger.debug('Looking for pymobiledevice3 pairing record')
@@ -269,8 +286,9 @@ class LockdownClient(object):
 
         record_data = plistlib.dumps(pair_record)
 
-        client = usbmux.PlistProtocol(usbmux.MuxConnection.create_socket())
-        client.save_pair_record(self.udid, self.usbmux_device.devid, record_data)
+        client = usbmux.create_mux()
+        if isinstance(client, PlistMuxConnection):
+            client.save_pair_record(self.udid, self.usbmux_device.devid, record_data)
 
         self.paired = True
 
@@ -336,14 +354,16 @@ class LockdownClient(object):
     @reconnect_on_remote_close
     def start_service(self, name, escrow_bag=None) -> ServiceConnection:
         attr = self.get_service_connection_attributes(name, escrow_bag=escrow_bag)
-        service_connection = ServiceConnection.create(self.udid, attr['Port'])
+        service_connection = ServiceConnection.create(self.udid, attr['Port'],
+                                                      connection_type=self.usbmux_device.connection_type)
         if attr.get('EnableServiceSSL', False):
             service_connection.ssl_start(self.ssl_file, self.ssl_file)
         return service_connection
 
     async def aio_start_service(self, name, escrow_bag=None) -> ServiceConnection:
         attr = self.get_service_connection_attributes(name, escrow_bag=escrow_bag)
-        service_connection = ServiceConnection.create(self.udid, attr['Port'])
+        service_connection = ServiceConnection.create(self.udid, attr['Port'],
+                                                      connection_type=self.usbmux_device.connection_type)
         if attr.get('EnableServiceSSL', False):
             await service_connection.aio_ssl_start(self.ssl_file, self.ssl_file)
         return service_connection
